@@ -19,9 +19,7 @@ from zope.interface import Interface, implementer
 
 from pyams_form.ajax import ajax_form_config
 from pyams_form.field import Fields
-from pyams_form.group import Group
 from pyams_form.interfaces.form import IAJAXFormRenderer, IGroup
-from pyams_i18n.interfaces import II18n
 from pyams_layer.interfaces import IPyAMSLayer
 from pyams_portal.interfaces import IPortletPreviewer, MANAGE_TEMPLATE_PERMISSION
 from pyams_portal.portlets.cards import ICard, ICardsPortletSettings
@@ -238,7 +236,15 @@ class ICardForm(Interface):
 class CardAddForm(AdminModalAddForm):
     """Card add form"""
 
-    title = _("Add new card")
+    @property
+    def title(self):
+        translate = self.request.localizer.translate
+        portlet = self.context.configuration.get_portlet()
+        return '<small>{}</small><br />{}'.format(
+            translate(_("Portlet configuration: « {} »")).format(portlet.label),
+            translate(_("Add new card"))
+        )
+
     legend = _("New card properties")
     modal_class = 'modal-xl'
 
@@ -282,8 +288,12 @@ class CardEditForm(AdminModalEditForm):
 
     @property
     def title(self):
-        """Title getter"""
-        return II18n(self.context).query_attribute('title', request=self.request)
+        translate = self.request.localizer.translate
+        portlet = self.context.__parent__.configuration.get_portlet()
+        return '<small>{}</small><br />{}'.format(
+            translate(_("Portlet configuration: « {} »")).format(portlet.label),
+            translate(_("Card: {}")).format(get_object_label(self.context, self.request, self))
+        )
 
     legend = _("Card properties")
     modal_class = 'modal-xl'
